@@ -16,7 +16,13 @@
 #------------------------------------------------------------------------------
 
 class AccessibleObjectNoLongerExists(Exception):
-        def __init__ (self): self._message = ""
+
+        def __init__ (self, message=None):
+                if message:
+                        self._message = message
+                else:
+                        self._message = ""
+
         def _get_message(self, message): return self._message
         def _set_message(self, message): self._message = message
         message = property(_get_message, _set_message)
